"""
Extension for the `test` cog.
Loading this file via `commands.Bot.load_extension` will add the `test` cog to the bot.
"""

import logging

import textwrap
from markdownify import markdownify
from discord import app_commands, Interaction, Embed
from discord.ext import commands, tasks
from sqlalchemy import insert, select

from db import DatabaseManager, AuditModel
from feed import Article, Source, Parser, Feeds, get_source

log = logging.getLogger(__name__)


class Test(commands.Cog):
    """
    News cog.
    Delivers embeds of news articles to discord channels.
    """

    def __init__(self, bot):
        super().__init__()
        self.bot = bot

    @commands.Cog.listener()
    async def on_ready(self):
        log.info(f"{self.__class__.__name__} cog is ready")

    @app_commands.command(name="test-bbc")
    async def test_command(self, inter: Interaction):

        await inter.response.defer()
        await self.bot.audit("Requesting latest article.", inter.user_id)

        source = get_source(Feeds.THE_UPPER_LIP)
        article = source.get_latest_article()

        md_description = markdownify(article.description)
        article_description = textwrap.shorten(md_description, 4096)

        embed = Embed(
            title=article.title,
            description=article_description,
            url=article.url,
        )
        embed.set_author(
            name=source.name,
            url=source.url,
            icon_url=source.icon_url
        )

        await inter.followup.send(embed=embed)

    @app_commands.command(name="test-upperlip")
    async def test_command(self, inter: Interaction):

        await inter.response.defer()
        await self.bot.audit("Requesting latest article.", inter.user_id)

        source = get_source(Feeds.THE_UPPER_LIP)
        article = source.get_latest_article()

        md_description = markdownify(article.description)
        article_description = textwrap.shorten(md_description, 4096)

        embed = Embed(
            title=article.title,
            description=article_description,
            url=article.url,
        )
        embed.set_author(
            name=source.name,
            url=source.url,
            icon_url=source.icon_url
        )

        await inter.followup.send(embed=embed)


async def setup(bot):
    """
    Setup function for this extension.
    Adds the `ErrorCog` cog to the bot.
    """

    cog = Test(bot)
    await bot.add_cog(cog)
    log.info(f"Added {cog.__class__.__name__} cog")
